@@ -4,8 +4,11 @@ from mindsdb_native.libs.data_types.data_source import DataSource
 
 
 class MSSQLDS(DataSource):
-    def _setup(self, query=None, host='localhost', user='sa', password='',
-               database='master', port=1433, table=None):
+    def _setup(self, table=None, query=None, database='master', host='localhost',
+               port=1433, user='sa', password=''):
+
+        self._database_name = database
+        self._table_name = table
 
         if query is None:
             query = f'SELECT * FROM {table}'
@@ -21,3 +24,10 @@ class MSSQLDS(DataSource):
             col_map[col] = col
 
         return df, col_map
+
+    def name(self):
+        return '{}: {}/{}'.format(
+            self.__class__.__name__,
+            self._database_name,
+            self._table_name
+        )
\ No newline at end of file
